%global service ironic-inspector
%{!?upstream_version: %global upstream_version %{version}}

Name:       openstack-ironic-inspector
Summary:    Hardware introspection service for OpenStack Ironic
Version:    4.2.2
Release:    6%{?dist}
License:    ASL 2.0
URL:        https://launchpad.net/ironic-inspector

Source0:    http://tarballs.openstack.org/%{service}/%{service}-%{version}.tar.gz
Source1:    openstack-ironic-inspector.service
Source2:    openstack-ironic-inspector-dnsmasq.service
Source3:    dnsmasq.conf
Source4:    ironic-inspector-rootwrap-sudoers
Source5:    ironic-inspector.logrotate
Source6:    ironic-inspector-dist.conf

#
# patches_base=+1
#
Patch0001: 0001-grenade-Only-enable_plugin-ironic-inspector-if-not-a.patch
Patch0002: 0002-Devstack-cleanup-upgrade-settings.patch
Patch0003: 0003-Use-eventlet-version-of-subprocess.patch
Patch0004: 0004-Ensure-root-device-hints-are-case-insensitive.patch
Patch0005: 0005-Eliminate-SQL-injection-vulnerability-in-node_cache.patch

BuildArch:  noarch
BuildRequires: python2-devel
BuildRequires: python-pbr
BuildRequires: systemd
# All these are required to run tests during check step
BuildRequires: python-mock
BuildRequires: python-babel
BuildRequires: python-eventlet
BuildRequires: python-fixtures
BuildRequires: python-flask
BuildRequires: python-futurist
BuildRequires: python-ironicclient
BuildRequires: python-jsonpath-rw
BuildRequires: python-jsonschema
BuildRequires: python-keystoneclient
BuildRequires: python-keystonemiddleware
BuildRequires: python-oslo-concurrency
BuildRequires: python-oslo-config
BuildRequires: python-oslo-db
BuildRequires: python-oslo-i18n
BuildRequires: python-oslo-log
BuildRequires: python-oslo-middleware
BuildRequires: python-oslo-sphinx
BuildRequires: python-oslo-utils
BuildRequires: python-oslotest
BuildRequires: python-six
BuildRequires: python-sphinx
BuildRequires: python-stevedore
BuildRequires: python-swiftclient
BuildRequires: python-testscenarios
BuildRequires: python-testresources

Requires: dnsmasq
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: python-babel
Requires: python-eventlet
Requires: python-flask
Requires: python-futurist
Requires: python-ironicclient
Requires: python-jsonpath-rw
Requires: python-jsonschema
Requires: python-keystoneclient
Requires: python-keystonemiddleware
Requires: python-oslo-concurrency
Requires: python-oslo-config
Requires: python-oslo-db
Requires: python-oslo-i18n
Requires: python-oslo-log
Requires: python-oslo-middleware
Requires: python-oslo-rootwrap
Requires: python-oslo-utils
Requires: python-six
Requires: python-stevedore
Requires: python-swiftclient

Obsoletes: openstack-ironic-discoverd < 1.1.1
Provides: openstack-ironic-discoverd = %{upstream_version}


%description
Ironic Inspector is an auxiliary service for discovering hardware properties
for a node managed by OpenStack Ironic. Hardware introspection or hardware
properties discovery is a process of getting hardware parameters required for
scheduling from a bare metal node, given it’s power management credentials
(e.g. IPMI address, user name and password).

%package -n openstack-ironic-inspector-doc
Summary:    Documentation for Ironic Inspector.

%description -n openstack-ironic-inspector-doc
Documentation for Ironic Inspector.

%prep
%autosetup -v -p 1 -n %{service}-%{upstream_version}
# Remove the requirements file so that pbr hooks don't add it
# to distutils requires_dist config
rm -rf {test-,plugin-,}requirements.txt

%build
%{__python2} setup.py build
%{__python2} setup.py build_sphinx

%install
%{__python2} setup.py install --skip-build --root=%{buildroot}
mkdir -p %{buildroot}%{_mandir}/man8
install -p -D -m 644 ironic-inspector.8 %{buildroot}%{_mandir}/man8/

# logs configuration
install -d -m 750 %{buildroot}%{_localstatedir}/log/ironic-inspector
install -d -m 750 %{buildroot}%{_localstatedir}/log/ironic-inspector/ramdisk
install -p -D -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/openstack-ironic-inspector

# install systemd scripts
mkdir -p %{buildroot}%{_unitdir}
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}

# install sudoers file
mkdir -p %{buildroot}%{_sysconfdir}/sudoers.d
install -p -D -m 440 %{SOURCE4} %{buildroot}%{_sysconfdir}/sudoers.d/ironic-inspector

# configuration contains passwords, thus 640
install -p -D -m 640 example.conf %{buildroot}/%{_sysconfdir}/ironic-inspector/inspector.conf
install -p -D -m 640 %{SOURCE6} %{buildroot}/%{_sysconfdir}/ironic-inspector/inspector-dist.conf
install -p -D -m 644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/ironic-inspector/dnsmasq.conf

# rootwrap configuration
mkdir -p %{buildroot}%{_sysconfdir}/ironic-inspector/rootwrap.d
install -p -D -m 640 rootwrap.conf %{buildroot}/%{_sysconfdir}/ironic-inspector/rootwrap.conf
install -p -D -m 640 rootwrap.d/* %{buildroot}/%{_sysconfdir}/ironic-inspector/rootwrap.d/

# shared state directory for sqlite database
mkdir -p %{buildroot}%{_sharedstatedir}/ironic-inspector

%check
%{__python2} -m unittest discover ironic_inspector.test.unit

%files
%doc README.rst
%license LICENSE
%config(noreplace) %attr(-,root,ironic-inspector) %{_sysconfdir}/ironic-inspector
%config(noreplace) %{_sysconfdir}/logrotate.d/openstack-ironic-inspector
%{_sysconfdir}/sudoers.d/ironic-inspector
%{python2_sitelib}/ironic_inspector*
%{_bindir}/ironic-inspector
%{_bindir}/ironic-inspector-rootwrap
%{_bindir}/ironic-inspector-dbsync
%{_unitdir}/openstack-ironic-inspector.service
%{_unitdir}/openstack-ironic-inspector-dnsmasq.service
%attr(-,ironic-inspector,ironic-inspector) %{_sharedstatedir}/ironic-inspector
%attr(-,ironic-inspector,ironic-inspector) %{_localstatedir}/log/ironic-inspector
%attr(-,ironic-inspector,ironic-inspector) %{_localstatedir}/log/ironic-inspector/ramdisk/
%doc %{_mandir}/man8/ironic-inspector.8.gz

%files -n openstack-ironic-inspector-doc
%license LICENSE
%doc CONTRIBUTING.rst doc/build/html

%pre
getent group ironic-inspector >/dev/null || groupadd -r ironic-inspector
getent passwd ironic-inspector >/dev/null || \
    useradd -r -g ironic-inspector -d %{_sharedstatedir}/ironic-inspector -s /sbin/nologin \
-c "OpenStack Ironic Inspector Daemons" ironic-inspector
exit 0

%post
%systemd_post openstack-ironic-inspector.service
%systemd_post openstack-ironic-inspector-dnsmasq.service

%preun
%systemd_preun openstack-ironic-inspector.service
%systemd_preun openstack-ironic-inspector-dnsmasq.service

%postun
%systemd_postun_with_restart openstack-ironic-inspector.service
%systemd_postun_with_restart openstack-ironic-inspector-dnsmasq.service

%changelog
* Tue May 21 2019 Bob Fournier <bfournie@redhat.com> 4.2.2-6
- Eliminate SQL injection vulnerability in node_cache (rhbz#1712182)

* Thu Aug 16 2018 Bob Fournier <bfournie@redhat.com> 4.2.2-5
- Ensure root device hints are case insensitive (rhbz#1571740)

* Thu Feb 01 2018 Steve Linabery <slinaber@redhat.com> 4.2.2-4
- Use eventlet version of subprocess (rhbz#1540590)

* Mon Aug 14 2017 Jason Joyce <jjoyce@redhat.com> 4.2.2-3
- Start ironic-inspector services after network.target is reached (rhbz#1452610)
- Prevent logs directory from being world-readable (rhbz#1431483)

* Thu Aug 03 2017 Steve Linabery <slinaber@redhat.com> 4.2.2-2
- [Devstack] cleanup upgrade settings
- grenade: Only 'enable_plugin ironic-inspector' if not already in conf

* Thu Aug 03 2017 Steve Linabery <slinaber@redhat.com> 4.2.2-1
- Update to 4.2.2

* Mon Feb 13 2017 Jon Schlueter <jschluet@redhat.com> 4.2.1-3
- rhbz#1421828
- Prepare for using standard python tests
- Do not use loopback BMC addresses for lookup (lp#1651719)
- Make grenade actually upgrade our source code
- Cherry-pick fixes for Grenade

* Fri Jan 13 2017 Jon Schlueter <jschluet@redhat.com> 4.2.1-2
- Remove upgrade from non-ironic setup
- Remove default_params_with_timeout_values from tempest client (lp#1614516)
- Switch func3 environment to Python 3.5
- Don't recreate db during grenade upgrade (lp#1644204)
- Stop disabling the Neutron tempest plugin (lp#1621791)

* Mon Nov 28 2016 Jason Joyce <jjoyce@redhat.com> 4.2.1-1
- Update to 4.2.1

* Fri Nov 18 2016 Jon Schlueter <jschluet@redhat.com> 4.2.0-3
- Remove the generic eventlet monkey patch from test (rhbz#1394744)

* Wed Oct 26 2016 Jon Schlueter <jschluet@redhat.com> 4.2.0-2
- Only disable Neutron tests when our Grenade is running
- LLC Hook: Do not assume interfaces are added to Ironic
- LLC Hook: Fix patching Ironic ports
- Update UPPER_CONSTRAINTS_FILE for stable/newton

* Thu Sep 22 2016 Haikel Guemar <hguemar@fedoraproject.org> 4.2.0-1
- Update to 4.2.0

* Wed Sep 14 2016 Haikel Guemar <hguemar@fedoraproject.org> 4.1.0-1
- Update to 4.1.0

